@@ -22,7 +22,7 @@
 class CControllerPopupLldOverride extends CController {
 
 	protected function init() {
-		$this->disableSIDvalidation();
+		$this->disableCsrfValidation();
 	}
 
 	protected function checkInput() {
@@ -97,7 +97,12 @@ class CControllerPopupLldOverride extends CController {
 					unset($page_options['overrides_filters'][$i]);
 				}
 			}
-			$page_options['overrides_filters'] = array_values($page_options['overrides_filters']);
+
+			if ($page_options['overrides_filters']) {
+				$page_options['overrides_filters'] = sortLldRuleFilterConditions($page_options['overrides_filters'],
+					$page_options['overrides_evaltype']
+				);
+			}
 
 			// Return collected error messages.
 			if ($messages = get_and_clear_messages()) {
@@ -125,6 +130,15 @@ class CControllerPopupLldOverride extends CController {
 			);
 		}
 		else {
+			if (!$page_options['overrides_filters']) {
+				$page_options['overrides_filters'][] = [
+					'macro' => '',
+					'operator' => CONDITION_OPERATOR_REGEXP,
+					'value' => '',
+					'formulaid' => num2letter(0)
+				];
+			}
+
 			$data = [
 				'title' => _('Override'),
 				'options' => $page_options,
