@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2023 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 class CControllerScriptList extends CController {
 
 	protected function init() {
-		$this->disableSIDValidation();
+		$this->disableCsrfValidation();
 	}
 
 	protected function checkInput() {
@@ -84,7 +84,7 @@ class CControllerScriptList extends CController {
 		$limit = CSettingsHelper::get(CSettingsHelper::SEARCH_LIMIT) + 1;
 		$data['scripts'] = API::Script()->get([
 			'output' => ['scriptid', 'name', 'command', 'host_access', 'usrgrpid', 'groupid', 'type', 'execute_on',
-				'scope'
+				'scope', 'menu_path'
 			],
 			'search' => [
 				'name' => ($filter['name'] === '') ? null : $filter['name']
@@ -97,8 +97,20 @@ class CControllerScriptList extends CController {
 			'preservekeys' => true
 		]);
 
-		// Data sort and pager.
-		order_result($data['scripts'], $sortField, $sortOrder);
+		// Data sort and pager. Trim down menu path and combine with name.
+		foreach ($data['scripts'] as &$script) {
+			$script['menu_path'] = trimPath($script['menu_path']);
+			$script['menu_path'] = trim($script['menu_path'], '/');
+			$script['name_full'] = $script['menu_path'] === ''
+				? $script['name']
+				: $script['menu_path'].'/'.$script['name'];
+		}
+		unset($script);
+
+		CArrayHelper::sort($data['scripts'], [[
+			'field' => $sortField === 'name' ? 'name_full' : $sortField,
+			'order' => $sortOrder
+		]]);
 
 		$page_num = getRequest('page', 1);
 		CPagerHelper::savePage('script.list', $page_num);
@@ -144,7 +156,7 @@ class CControllerScriptList extends CController {
 			$script_actions = API::Script()->get([
 				'output' => [],
 				'scriptids' => array_keys($action_scriptids),
-				'selectActions' => ['actionid', 'name'],
+				'selectActions' => ['actionid', 'name', 'eventsource'],
 				'preservekeys' => true
 			]);
 
