@@ -40,13 +40,23 @@ $fields = [
 	'filter_groups' =>		[T_ZBX_INT,			O_OPT,	P_SYS|P_ONLY_ARRAY,	DB_ID,	null],
 	'filter_hostids' =>		[T_ZBX_INT,			O_OPT,	P_SYS|P_ONLY_ARRAY,	DB_ID,	null],
 	'filter_templateid' =>	[T_ZBX_INT,			O_OPT,	P_SYS,				DB_ID,	null],
-	'filter_rst'=>			[T_ZBX_STR,			O_OPT,	P_SYS,			null,		null],
-	'filter_set' =>			[T_ZBX_STR,			O_OPT,	P_SYS,			null,		null],
-	'from' =>				[T_ZBX_RANGE_TIME,	O_OPT,	P_SYS,			null,		null],
-	'to' =>					[T_ZBX_RANGE_TIME,	O_OPT,	P_SYS,			null,		null]
+	'filter_rst'=>			[T_ZBX_STR,			O_OPT,	P_SYS,				null,	null],
+	'filter_set' =>			[T_ZBX_STR,			O_OPT,	P_SYS,				null,	null],
+	'from' =>				[T_ZBX_RANGE_TIME,	O_OPT,	P_SYS,				null,	null],
+	'to' =>					[T_ZBX_RANGE_TIME,	O_OPT,	P_SYS,				null,	null]
 ];
 check_fields($fields);
-validateTimeSelectorPeriod(getRequest('from'), getRequest('to'));
+
+if (hasRequest('from') || hasRequest('to')) {
+	validateTimeSelectorPeriod(
+		hasRequest('from') ? getRequest('from') : null,
+		hasRequest('to') ? getRequest('to') : null
+	);
+}
+
+$timeselector_from = getRequest('from', CProfile::get('web.avail_report.filter.from',
+	'now-'.CSettingsHelper::get(CSettingsHelper::PERIOD_DEFAULT)));
+$timeselector_to = getRequest('to', CProfile::get('web.avail_report.filter.to', 'now'));
 
 $report_mode = getRequest('mode', CProfile::get('web.avail_report.mode', AVAILABILITY_REPORT_BY_HOST));
 CProfile::update('web.avail_report.mode', $report_mode, PROFILE_TYPE_INT);
@@ -92,6 +102,8 @@ if (hasRequest('filter_set')) {
 		CProfile::update($key_prefix.'.hostgroupid', getRequest('hostgroupid', 0), PROFILE_TYPE_ID);
 	}
 	else {
+		CProfile::update('web.avail_report.filter.from', $timeselector_from, PROFILE_TYPE_STR);
+		CProfile::update('web.avail_report.filter.to', $timeselector_to, PROFILE_TYPE_STR);
 		CProfile::updateArray($key_prefix.'.groupids', getRequest('filter_groups', []), PROFILE_TYPE_ID);
 		CProfile::updateArray($key_prefix.'.hostids', getRequest('filter_hostids', []), PROFILE_TYPE_ID);
 	}
@@ -128,15 +140,6 @@ $data['filter'] = ($report_mode == AVAILABILITY_REPORT_BY_TEMPLATE)
 		'hostids' => CProfile::getArray($key_prefix.'.hostids', getRequest('filter_hostids', []))
 	];
 
-// Get time selector filter values.
-$timeselector_options = [
-	'profileIdx' => 'web.avail_report.filter',
-	'profileIdx2' => 0,
-	'from' => getRequest('from'),
-	'to' => getRequest('to')
-];
-updateTimeSelectorPeriod($timeselector_options);
-
 /*
  * Header
  */
@@ -149,7 +152,7 @@ $triggerData = isset($_REQUEST['triggerid'])
 	])
 	: null;
 
-$reportWidget = (new CWidget())
+$html_page = (new CHtmlPage())
 	->setTitle(_('Availability report'))
 	->setDocUrl(CDocHelper::getUrl(CDocHelper::REPORT2));
 
@@ -160,7 +163,7 @@ if ($triggerData) {
 	$triggerData['hostid'] = $host['hostid'];
 	$triggerData['hostname'] = $host['name'];
 
-	$reportWidget->setControls((new CTag('nav', true,
+	$html_page->setControls((new CTag('nav', true,
 		(new CList())
 			->addItem(new CLink($triggerData['hostname'], (new CUrl('report2.php'))
 				->setArgument('page', CPagerHelper::loadPage('report2.php', null))
@@ -173,7 +176,7 @@ if ($triggerData) {
 	$table = (new CTableInfo())
 		->addRow(new CImg('chart4.php?triggerid='.$_REQUEST['triggerid']));
 
-	$reportWidget->addItem(BR())
+	$html_page->addItem(BR())
 		->addItem($table)
 		->show();
 }
@@ -188,8 +191,7 @@ else {
 		->addOption(new CSelectOption(AVAILABILITY_REPORT_BY_HOST, _('By host')))
 		->addOption(new CSelectOption(AVAILABILITY_REPORT_BY_TEMPLATE, _('By trigger template')));
 
-	$reportWidget->setControls((new CForm('get'))
-		->cleanItems()
+	$html_page->setControls((new CForm('get'))
 		->setAttribute('aria-label', _('Main filter'))
 		->addItem((new CList())
 			->addItem([
@@ -205,7 +207,12 @@ else {
 	 * Filter
 	 */
 	$data['filter'] += [
-		'timeline' => getTimeSelectorPeriod($timeselector_options),
+		'timeline' => getTimeSelectorPeriod([
+			'profileIdx' => 'web.avail_report.filter',
+			'profileIdx2' => 0,
+			'from' => $timeselector_from,
+			'to' => $timeselector_to
+		]),
 		'active_tab' => CProfile::get('web.avail_report.filter.active', 1)
 	];
 
@@ -464,8 +471,9 @@ else {
 					'object_name' => 'hosts',
 					'data' => $data['filter']['hostids'],
 					'popup' => [
-						'filter_preselect_fields' => [
-							'hostgroups' => 'filter_groups_'
+						'filter_preselect' => [
+							'id' => 'filter_groups_',
+							'submit_as' => 'groupid'
 						],
 						'parameters' => [
 							'srctbl' => 'hosts',
@@ -486,14 +494,15 @@ else {
 	}
 	unset($trigger);
 
-	$reportWidget->addItem(
+	$html_page->addItem(
 		(new CFilter())
 			->setResetUrl(new CUrl('report2.php'))
 			->setProfile($data['filter']['timeline']['profileIdx'])
 			->setActiveTab($data['filter']['active_tab'])
 			->addFormItem((new CVar('mode', $report_mode))->removeId())
 			->addTimeSelector($data['filter']['timeline']['from'], $data['filter']['timeline']['to'], true,
-				ZBX_DATE_TIME)
+				'web.avail_report.filter', ZBX_DATE_TIME
+			)
 			->addFilterTab(_('Filter'), [$filter_column])
 	);
 
@@ -521,7 +530,7 @@ else {
 				? new CLink($trigger['description'],
 					(new CUrl('zabbix.php'))
 						->setArgument('action', 'problem.view')
-						->setArgument('filter_name', '')
+						->setArgument('filter_set', '1')
 						->setArgument('triggerids', [$trigger['triggerid']])
 				)
 				: $trigger['description'],
@@ -547,7 +556,7 @@ else {
 	);
 	zbx_add_post_js('timeControl.processObjects();');
 
-	$reportWidget
+	$html_page
 		->addItem([$triggerTable, $paging])
 		->show();
 }
