@@ -99,7 +99,7 @@ class WidgetProblems extends CTableInfo {
 				($this->data['sortfield'] === 'name')
 					? [_x('Problem', 'compact table header'), $sort_div]
 					: _x('Problem', 'compact table header'),
-				' &bullet; ',
+				' ', BULLET(), ' ',
 				($this->data['sortfield'] === 'severity')
 					? [_x('Severity', 'compact table header'), $sort_div]
 					: _x('Severity', 'compact table header')
@@ -124,7 +124,7 @@ class WidgetProblems extends CTableInfo {
 			'show_recovery_data' => $show_recovery_data
 		];
 
-		$this->addProblemsToTable($this->data['problems'], $this->data);
+		$this->addProblemsToTable($this->data['problems'], $this->data, false);
 
 		if ($this->data['info'] !== '') {
 			$this->setFooter([
@@ -173,7 +173,7 @@ class WidgetProblems extends CTableInfo {
 	 * @param array      $data['tags']                          List of tags.
 	 * @param bool       $nested                                If true, show the symptom rows with indentation.
 	 */
-	private function addProblemsToTable(array $problems, array $data, $nested = false): void {
+	private function addProblemsToTable(array $problems, array $data, $nested): void {
 		foreach ($problems as $problem) {
 			$trigger = $data['triggers'][$problem['objectid']];
 
@@ -341,9 +341,14 @@ class WidgetProblems extends CTableInfo {
 
 			$problem_link = [
 				(new CLinkAction($problem['name']))
-					->setMenuPopup(CMenuPopupHelper::getTrigger($trigger['triggerid'], $problem['eventid'],
-						['show_rank_change_cause' => true]
-					))
+					->setMenuPopup(CMenuPopupHelper::getTrigger([
+						'triggerid' => $trigger['triggerid'],
+						'backurl' => (new CUrl('zabbix.php'))
+							->setArgument('action', 'dashboard.view')
+							->getUrl(),
+						'eventid' => $problem['eventid'],
+						'show_rank_change_cause' => true
+					]))
 					->setAttribute('aria-label', _xs('%1$s, Severity, %2$s', 'screen reader',
 						$problem['name'], CSeverityHelper::getName((int) $problem['severity'])
 					))
@@ -459,7 +464,7 @@ class WidgetProblems extends CTableInfo {
 
 			if ($data['show_timeline']) {
 				if ($data['last_clock'] != 0) {
-					CScreenProblem::addTimelineBreakpoint($this, $data, $problem, $nested);
+					CScreenProblem::addTimelineBreakpoint($this, $data, $problem, $nested, false);
 				}
 				$data['last_clock'] = $problem['clock'];
 
